% pdesolve:
% demonstrate using of PDE Toolbox
% geometry initialized in make_geometry.m, then exported
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc; clear all; close all;

% load the data which have been prepared with PDE Toolbox
load('pde_initial.mat'); 

[K,F,B,ud] = assempde(b,p,e,t,c,a,f);

u1 = K\F     ; % find the non-dirichlet points
u = B*u1 + ud; % full solution

% compute grad(u) 
[ux,uy]=pdegrad(p,t,u);

% visualize
figure(1)
pdemesh(p,e,t);
axis equal; axis tight;
xlabel('x'); ylabel('y'); title('u');

figure(2);
pdesurf(p,t,u);
colormap jet
view(2); axis equal; colorbar; shading faceted; axis tight;
xlabel('x'); ylabel('y'); title('u');


% visualize the norm of the gradient
figure(3);
pdesurf(p,t,sqrt(ux.^2 + uy.^2));
colormap jet
view(2); axis equal; colorbar; shading faceted; axis tight;
xlabel('x'); ylabel('y'); title('||grad u||');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% make two refinements
[p,e,t] = refinemesh(g,p,e,t);
[p,e,t] = refinemesh(g,p,e,t);
[K,F,B,ud] = assempde(b,p,e,t,c,a,f);

u1 = K\F     ; % find the non-dirichlet points
u = B*u1 + ud; % full solution

% compute grad(u) 
[ux,uy]=pdegrad(p,t,u);

% visualize
figure(4)
pdemesh(p,e,t);
axis equal; axis tight;
xlabel('x'); ylabel('y'); title('u');

figure(5);
pdesurf(p,t,u);
colormap jet
view(2); axis equal; colorbar; shading faceted; axis tight;
xlabel('x'); ylabel('y'); title('u');


% visualize the norm of the gradient
figure(6);
pdesurf(p,t,sqrt(ux.^2 + uy.^2));
colormap jet
view(2); axis equal; colorbar; shading faceted; axis tight;
xlabel('x'); ylabel('y'); title('|| grad u ||');
